==> xmgfv1.9.1.tar.gz: xmgf/src/XmgfHelp.c <==
#include <stdio.h>

#include <X11/StringDefs.h>
#include <Xm/Xm.h>
#include <Xm/MessageB.h>
#include <XmgfDefines.h>

void
XmgfHelpCB(parent,client_data,call_data)
Widget parent;
caddr_t client_data;
caddr_t call_data;
{
    Widget mainhelp;
    Widget button;
    Arg args[20];
    register int n;
    int Reason = (int) client_data;

    static char message[1000],title[1000];
    XmString title_string = NULL;
    XmString message_string = NULL;
    XmString button_string = NULL;

    sprintf(title," Xmgf Help - Paul Hoad\n");
    sprintf(message,"\n");

    switch(Reason){
    case HELP_LOAD:
    strcat(message,"Loading\n");
    strcat(message,"Choose the File you wish to load\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"Saving\n");
    strcat(message,"Enter the Filename you wish to save it as\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"Moving Around\n");
    strcat(message,"If you want to walk around the directories edit\n");
    strcat(message,"the filter or move around using . and .. \n\n");
    strcat(message,"\n");break;
    case HELP_PRINT:
    strcat(message,"Enter the command that you use to print\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"for example\n");
    strcat(message," `lpr -Pps` or `print` \n");
    strcat(message,"\n");break;
    case HELP_MAIN:
    default:
    strcat(message,"Xmgf is a 3D gf/OFF/NFF Object viewer\n\n");
    strcat(message,"Select Load New Sets from the File menu\n");
    strcat(message,"Button 1 Select item\n");
    strcat(message,"Button 2 Translate objects\n");
    strcat(message,"Button 3 Rotate objects\n");
    strcat(message,"If you have problems rotating try using rotate guide\n");
    strcat(message,"\n");break;
    }

    title_string=XmStringCreateLtoR(title,XmSTRING_DEFAULT_CHARSET);
    message_string=XmStringCreateLtoR(message,XmSTRING_DEFAULT_CHARSET);
    button_string = XmStringCreateLtoR("Close",XmSTRING_DEFAULT_CHARSET);

    /* Setup a Message Box Widget to Display the Help Message */
    n=0;
    XtSetArg(args[n],XmNdialogTitle,title_string);n++;
    XtSetArg(args[n],XmNokLabelString,button_string);n++;
    XtSetArg(args[n],XmNmessageString,message_string);n++;
    mainhelp= XmCreateMessageDialog(parent,"mainhelp",args,n);

    /* Remove the Cancel and Help Buttons from the standard Message Box */
    button=XmMessageBoxGetChild(mainhelp,XmDIALOG_CANCEL_BUTTON);
    XtUnmanageChild(button);
    button=XmMessageBoxGetChild(mainhelp,XmDIALOG_HELP_BUTTON);
    XtUnmanageChild(button);

    /* Manage the Widget */
    XtManageChild(mainhelp);

    return;
}

==> xmgfv2.4.tar.gz: xmgf/src/XmgfHelp.c <==
static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";
/*
 * Copyright (C) 1992, 1993, 1994, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#include <stdio.h>

#include <X11/StringDefs.h>
#include <Xm/Xm.h>
#include <Xm/MessageB.h>
#include <XmgfDefines.h>
#include <Disp3DGF.h>

void
XmgfHelpCB(parent,client_data,call_data)
Widget parent;
caddr_t client_data;
caddr_t call_data;
{
    Widget mainhelp;
    Widget button;
    Arg args[20];
    char  buf[100];
    register int n;
    int Reason = (int) client_data;

    static char message[1000],title[1000];
    XmString title_string = NULL;
    XmString message_string = NULL;
    XmString button_string = NULL;

    sprintf(title," Xmgf Help - Paul Hoad\n");
    sprintf(message,"\n");

    switch(Reason){
    case HELP_LOAD:
    strcat(message,"Loading\n");
    strcat(message,"Choose the File you wish to load\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"Saving\n");
    strcat(message,"Enter the Filename you wish to save it as\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"Moving Around\n");
    strcat(message,"If you want to walk around the directories edit\n");
    strcat(message,"the filter or move around using . and .. \n\n");
    strcat(message,"\n");break;
    case HELP_PRINT:
    strcat(message,"Enter the command that you use to print\n");
    strcat(message,"Then Press OK\n");
    strcat(message,"\n");
    strcat(message,"for example\n");
    strcat(message," `lpr -Pps` or `print` \n");
    strcat(message,"\n");break;
    case HELP_MOSAIC:
    case HELP_MAIN:
    default:
#ifdef USE_MOSAICHELP
    strcat(message," Xmgf Help System :-\n");
    strcat(message," Running NCSA's Mosaic based Hypertext Help!\n");
    strcat(message,"\n");
    sprintf(buf, "%s %s/%s &",appres.MosaicCmd,appres.HelpDir,appres.HelpFile);
    system(buf);
#else
    strcat(message,"Xmgf is a 3D gf/OFF/NFF Object viewer\n\n");
    strcat(message,"\n HYPERTEXT HELP SYSTEM TURNED OFF\n");
    strcat(message,"Select Load New Sets from the File menu\n");
    strcat(message,"Button 1 Select item\n");
    strcat(message,"Button 2 Translate objects\n");
    strcat(message,"Button 3 Rotate objects\n");
    strcat(message,"If you have problems rotating try using rotate guide\n");
    strcat(message,"\n");
#endif

    break;
    }

    title_string=XmStringCreateLtoR(title,XmSTRING_DEFAULT_CHARSET);
    message_string=XmStringCreateLtoR(message,XmSTRING_DEFAULT_CHARSET);
    button_string = XmStringCreateLtoR("Close",XmSTRING_DEFAULT_CHARSET);

    /* Setup a Message Box Widget to Display the Help Message */
    n=0;
    XtSetArg(args[n],XmNdialogTitle,title_string);n++;
    XtSetArg(args[n],XmNokLabelString,button_string);n++;
    XtSetArg(args[n],XmNmessageString,message_string);n++;
    mainhelp= XmCreateMessageDialog(parent,"mainhelp",args,n);

    /* Remove the Cancel and Help Buttons from the standard Message Box */
    button=XmMessageBoxGetChild(mainhelp,XmDIALOG_CANCEL_BUTTON);
    XtUnmanageChild(button);
    button=XmMessageBoxGetChild(mainhelp,XmDIALOG_HELP_BUTTON);
    XtUnmanageChild(button);

    /* Manage the Widget */
    XtManageChild(mainhelp);

    return;
}
